@@ -5,7 +5,7 @@ from typing import Generator, List, Optional
 import typer
 
 from . import __doc__, __name__, version_callback
-from .utils import pathu, refactor, regexu, report
+from .utils import iou, pathu, refactor, regexu, report
 from .utils.config import Config
 
 app = typer.Typer(name=__name__, add_completion=True)
@@ -14,6 +14,21 @@ app = typer.Typer(name=__name__, add_completion=True)
 @app.command(context_settings=dict(help_option_names=["-h", "--help"]))
 def main(  # pylint: disable=R0913,R0914
     paths: List[Path] = typer.Argument(None, help="Directories or files paths."),
+    skip_imports: List[str] = typer.Option(
+        [],
+        "--skip-imports",
+        show_default=False,
+        help=(
+            "A list of module/package names to be skipped globally."
+            " This works similar to `# nopycln: import`"
+            " (to skip certain import statements)"
+            " but at a global scope where you provide a comma separated list"
+            " of module/package/library names"
+            " to be skipped via the CLI option like `--skip-imports os,time,pycln`"
+            " or by passing a list via a config file"
+            " such as `skip_imports: [os, time, pycln]` (recommended)."
+        ),
+    ),
     config: Optional[Path] = typer.Option(
         None,
         "--config",
@@ -141,6 +156,7 @@ def main(  # pylint: disable=R0913,R0914
 ):
     configs = Config(
         paths=paths,
+        skip_imports=set(skip_imports),
         config=config,
         include=include,  # type: ignore
         exclude=exclude,  # type: ignore
@@ -157,17 +173,20 @@ def main(  # pylint: disable=R0913,R0914
     reporter = report.Report(configs)
     session_maker = refactor.Refactor(configs, reporter)
     for path in configs.paths:
-        gitignore = regexu.get_gitignore(
-            path if path.is_dir() else path.parent, configs.no_gitignore
-        )
-        sources: Generator = pathu.yield_sources(
-            path,
-            configs.include,
-            configs.exclude,
-            configs.extend_exclude,
-            gitignore,
-            reporter,
-        )
+        if path == iou.STDIN_NOTATION:
+            sources: List[Path] = [iou.STDIN_FILE]
+        else:
+            gitignore = regexu.get_gitignore(
+                path if path.is_dir() else path.parent, configs.no_gitignore
+            )
+            sources: Generator = pathu.yield_sources(  # type: ignore
+                path,
+                configs.include,
+                configs.exclude,
+                configs.extend_exclude,
+                gitignore,
+                reporter,
+            )
         for source in sources:
             session_maker.session(source)
     # Print the report.
