@@ -1,7 +1,6 @@
 """Pycln code refactoring utility."""
 import ast
 import os
-from functools import lru_cache
 from importlib import import_module
 from pathlib import Path
 from typing import Iterable, List, Optional, Set, Tuple, Union, cast
@@ -91,7 +90,7 @@ class Refactor:
             #: Remove any `ast.Pass` node
             #: that is both useless and not in the `wl` (white list).
             #:
-            #: The below case is not going to be touched:
+            #: The case below is not going to be touched:
             #:
             #: >>> (async) (def) (class) foo:
             #: >>>      """DOCString"""
@@ -141,15 +140,18 @@ class Refactor:
         """
         self._path = path
         try:
-            # Safly read the file.
-            permissions = [os.R_OK]
-            if not self.configs.check and not self.configs.diff:
-                permissions.append(os.W_OK)
-            content, encoding, newlines = iou.safe_read(self._path, tuple(permissions))
+            if path == iou.STDIN_FILE:
+                content, encoding, newline = iou.read_stdin()
+            else:
+                permissions = [os.R_OK]
+                if not self.configs.check and not self.configs.diff:
+                    permissions.append(os.W_OK)
+                content, encoding, newline = iou.safe_read(
+                    self._path, tuple(permissions)
+                )
 
-            # Refactor and output the `content`.
             fixed_lines = self._code_session(content).splitlines(True)
-            self._output(fixed_lines, content.splitlines(True), encoding, newlines)
+            self._output(fixed_lines, content.splitlines(True), encoding, newline)
         except (
             ReadPermissionError,
             WritePermissionError,
@@ -186,16 +188,18 @@ class Refactor:
         fixed_lines: List[str],
         original_lines: List[str],
         encoding: str,
-        newlines: str,
+        newline: str,
     ) -> None:
         """Output the given `fixed_lines`.
 
         :param fixed_lines: the refactored source lines.
         :param original_lines: unmodified source lines.
         :param encoding: file encoding.
-        :param newlines: original file newlines (CRFL | FL).
+        :param newline: original file newline (CRFL | FL).
         """
         if fixed_lines == original_lines:
+            if self._path == iou.STDIN_FILE:
+                self.reporter.output_stdin_to_stdout(fixed_lines)
             self.reporter.unchanged_file(self._path)
         else:
             self.reporter.changed_file(self._path)
@@ -206,7 +210,10 @@ class Refactor:
                         self._path, original_lines, fixed_lines
                     )
                 else:
-                    iou.safe_write(self._path, fixed_lines, encoding, newlines)
+                    if self._path == iou.STDIN_FILE:
+                        self.reporter.output_stdin_to_stdout(fixed_lines)
+                    else:
+                        iou.safe_write(self._path, fixed_lines, encoding, newline)
 
     def _analyze(
         self, tree: ast.AST, original_lines: List[str]
@@ -368,6 +375,11 @@ class Refactor:
         try:
             is_star = False
             if node.names[0].name == "*":
+
+                if node.module:
+                    if node.module.split(".")[0] in self.configs.skip_imports:
+                        return node, None
+
                 is_star = True
                 node = cast(ImportFrom, scan.expand_import_star(node, self._path))
             return node, is_star
@@ -403,6 +415,10 @@ class Refactor:
         """
         real_name = node.module if isinstance(node, ImportFrom) else alias.name
         used_name = alias.asname if alias.asname else alias.name
+
+        if real_name and real_name.split(".")[0] in self.configs.skip_imports:
+            return False
+
         if (
             not self._has_used(used_name, is_star)
             and real_name not in pathu.IMPORTS_WITH_SIDE_EFFECTS
@@ -439,9 +455,8 @@ class Refactor:
                 [name in self._source_stats.attr_ for name in name[1:]]
             )
 
-    @lru_cache()
-    def _has_side_effects(
-        self, module: str, node: Union[Import, ImportFrom]
+    def _has_side_effects(  # pylint: disable=dangerous-default-value
+        self, module: str, node: Union[Import, ImportFrom], *, cache: dict = {}
     ) -> scan.HasSideEffects:
         """Check if the given import file tree has side effects.
 
@@ -459,20 +474,30 @@ class Refactor:
         if not module_source:
             return scan.HasSideEffects.NOT_MODULE
 
+        cached_result = cache.get(module_source, None)
+        if cached_result is not None:
+            return cached_result  # pragma: nocover
+
         try:
             code, _, _ = iou.safe_read(module_source, permissions=(os.R_OK,))
             tree = scan.parse_ast(code, module_source)
         except (ReadPermissionError, UnparsableFile) as err:
             self.reporter.failure(str(err))
-            return scan.HasSideEffects.NOT_KNOWN
+            assumption = scan.HasSideEffects.NOT_KNOWN
+            cache[module_source] = assumption
+            return assumption
 
         try:
             analyzer = scan.SideEffectsAnalyzer()
             analyzer.visit(tree)
-            return analyzer.has_side_effects()
+            assumption = analyzer.has_side_effects()
+            cache[module_source] = assumption
+            return assumption
         except Exception as err:
             self.reporter.failure(str(err), self._path)
-            return scan.HasSideEffects.NOT_KNOWN
+            assumption = scan.HasSideEffects.NOT_KNOWN
+            cache[module_source] = assumption
+            return assumption
 
     @staticmethod
     def _insert(
